@@ -3,11 +3,12 @@ header = function()
 {
   tags$head(
     tags$title("dextergui"),
-    tags$script(src = "shinydexter/jquery.sparkline.min.js"),
-    tags$script(src = "shinydexter/jquery-ui.min.js"),
     tags$link(href = "shinydexter/shinydexter.css", type='text/css', rel='stylesheet'),
     tags$link(href = "shinydexter/jquery-ui.min.css", type='text/css', rel='stylesheet'),
+    tags$script(src = "shinydexter/jquery.sparkline.min.js"),
+    tags$script(src = "shinydexter/jquery-ui.min.js"),
     tags$script(src = "shinydexter/jquery.mousewheel.min.js"),
+    tags$script(src = "shinydexter/zoom.js"),
     tags$script(src = "shinydexter/patches.js"),
     tags$script(src = "shinydexter/pr_helper.js"),
     tags$script(src = "shinydexter/dt_extensions.js"),
@@ -21,7 +22,7 @@ get_ui = function()
 {
 	tagList(header(),		
 	useShinyjs(),
-	tags$div(tags$div(class='loader'),id='project_load_icon',style='display:none;'),
+	tags$div(tags$h1('Loading...'), tags$div(class='loader'),id='project_load_icon',style='display:none;'),
   navbarPage(title=NULL, id='main_navbar', position = 'fixed-top',
 		tabPanel('Project',
 		  tags$div(
@@ -134,25 +135,49 @@ get_ui = function()
 		      id='proj_persons_frm'),
 		    style='margin-left:0;')),
 		tabPanel('Data import',
-		  tags$h3('Import respons data', tags$a(tags$i(class="fa fa-question-circle"),class="btn btn-lg", 
-		                                        `data-toggle`='collapse',`data-target`='#help-import-data-file',
-		                                        style="position:relative;bottom:1px;")),
-		  fluidRow(
-		    column(width=3, class="col-side-left",
-		      tags$div('The data file should contain responses for one testform (booklet).',
-		               'Each row in the data file will be interpreted as the responses for a single person.',
-		               "The first row should contain column names. Most column names should correspond to item_id's",
-		               'that are known in your project. It is also possible to add extra columns which contain person properties,',
-		               'e.g. age, schooltype or other variables of interest. It is advisable to add another column named person_id',
-		               'which uniquely codes each person. This will prevent you from accidentally entering the same data twice.',
-		               id='help-import-data-file', class='collapse',style="margin-bottom:1em;"),
-  			  selectizeInput('add_booklet_name','Booklet id', choices=c('type or choose booklet_id' = ''),
-						             options=list(create=TRUE, createOnBlur=TRUE), width='100%'),
-			    fileInput('data_file', 'Data file',width='100%'),
-			    uiOutput('show_data_unknown_rsp', inline = TRUE),
-			    withBusyIndicatorUI(actionButton('go_import_data','Import',class='btn btn-primary')),
-			  htmlOutput('data_import_result')),
-			column(width=9, tableOutput('data_preview'))),
+		  tabsetPanel(id='data_input_format',
+		    tabPanel('Single booklet', value='wide',
+    		  tags$h3('Import respons data', tags$a(tags$i(class="fa fa-question-circle"),class="btn btn-lg", 
+    		                                        `data-toggle`='collapse',`data-target`='#help-import-data-file',
+    		                                        style="position:relative;bottom:1px;")),
+    		  fluidRow(
+    		    column(width=3, class="col-side-left",
+    		      tags$div(tags$p('Here you can import response data for a single booklet at a time with persons as rows',
+    		               'and items as columns.'),
+    		               tags$p("The first row should contain column names. Column names should correspond to item_id's",
+    		               'for which you have previously entered scoring rules. It is also possible to include',
+    		               'columns which contain person properties,',
+    		               'e.g. age, schooltype or other variables of interest.'),
+    		               tags$p('It is good practice to add another column',
+    		               'named person_id to uniquely identify each person. This will prevent you from accidentally entering', 
+    		               'the same data twice.'),
+    		               id='help-import-data-file', class='collapse',style="margin-bottom:1em;"),
+      			  fileInput('data_file', 'Data file',width='100%'),
+    		      selectizeInput('add_booklet_name','Booklet id', choices=c('type or choose booklet_id' = ''),
+    						             options=list(create=TRUE, createOnBlur=TRUE), width='100%'),
+    			    uiOutput('show_data_unknown_rsp', inline = TRUE),
+    			    withBusyIndicatorUI(actionButton('go_import_data','Import',class='btn btn-primary')),
+    			    htmlOutput('data_import_result')),
+    			column(width=9, tableOutput('data_preview')))),
+		    tabPanel('Long format', value='long',
+		      tags$h3('Import respons data', 
+		              tags$a(tags$i(class="fa fa-question-circle"),class="btn btn-lg", 
+		                     `data-toggle`='collapse',`data-target`='#help-import-data-file-long',
+		                      style="position:relative;bottom:1px;")),
+		      fluidRow(
+		        column(width=3, class="col-side-left",  
+		          tags$div(HTML('Here you can import response data in normalized or long format as can be typically exported',
+		                   'from databases. Dexter expects the columns:<ul><li>booklet_id</li><li>person_id</li><li>item_id</li>', 
+		                   '<li>response</li><li>item_position (optional)</li></ul>',
+		                   'Each row should contain a single response.'),
+		                  id='help-import-data-file-long', class='collapse',style="margin-bottom:1em;"),
+		          fileInput('data_file_long', 'Data file',width='100%'),
+		          uiOutput('show_data_unknown_rsp_long'),
+		          withBusyIndicatorUI(actionButton('go_import_data_long','Import',class='btn btn-primary')),
+		          htmlOutput('data_import_result_long')),
+		        column(width=9, tableOutput('data_preview_long'))))),
+		             
+		             
 		  value = 'data_pane',style="padding-left:10px;"),
 		tabPanel('Classical analysis',
 		  tabsetPanel(type = 'tabs', id = 'ctt_panels',
